#

##

##

##

##

    	recipe with goals

    	summary

    	utility
    		import legumes.recipe_with_goals.formulate as formulate_recipe_with_goals
    		formulate_recipe_with_goals.beautifully (
    			ingredients = [
    				[ retrieve_supp ("coated tablets/multivitamin_276336.JSON"), 10 ]
    			],
    			goals = {}
    		)

    	objectives
    		# agenda

    		[ ] columns
    			[ ] mass + mass equivalents, in grams, per package
    			[ ] percent of essential nutrient composition
    			[ ] days of nutrients

    	structure

    		'''
    			fake data: {
    				"info": {
    					"includes": [],
    					"names": [
    						"protein"
    					],
    					"region": 1
    				},
    				"measures": {
    					"mass + mass equivalents": {
    						"per recipe": {
    							"grams": {
    								"fraction string": "65193545255861875341/11258999068426240"
    							}
    						},
    						"portion of grove": {
    							"fraction string": "1303870905117237506820000/3661863958435401439007099"
    						}
    					}
    				},
    				"goals": {
    					"per day"
    						"mass + mass equivalents": {
    							"per recipe": {
    								"grams": {
    									"fraction string": "3/100000"
    								}
    							}
    						}
    					}
    				}
    			}
    		'''

    		'''
    			{
    				"labels": [ "Biotin" ],
    				"goal": {
    					"mass + mass equivalents": {
    						"per day": {
    							"grams": {
    								"fraction string": "3/100000"
    							}
    						}
    					}
    				}
    			}
    		'''

    		'''
    			days = amount in recipe / amount of goal
    		'''